aboutsummaryrefslogtreecommitdiff
path: root/src/northbridge/amd/amdfam10/misc_control.c
diff options
context:
space:
mode:
authorDamien Zammit <damien@zamaudio.com>2016-02-10 14:01:36 +1100
committerMartin Roth <martinroth@google.com>2016-03-30 16:23:07 +0200
commit33aaa921f7538761816900652e186b610d2ab35b (patch)
tree2288af51802352076b174dcac8afc0231465c6e6 /src/northbridge/amd/amdfam10/misc_control.c
parent27e085a8eea7f34ed4987b83c513d2f1818b33a1 (diff)
northbridge/amd/amdfam10: Add family15h model10h-1fh (Trinity)
Change-Id: I96d695ed10176276116fcf3a2b77605fb3f2d5db Signed-off-by: Damien Zammit <damien@zamaudio.com> Reviewed-on: https://review.coreboot.org/13710 Tested-by: build bot (Jenkins) Tested-by: Raptor Engineering Automated Test Stand <noreply@raptorengineeringinc.com> Reviewed-by: Martin Roth <martinroth@google.com>
Diffstat (limited to 'src/northbridge/amd/amdfam10/misc_control.c')
-rw-r--r--src/northbridge/amd/amdfam10/misc_control.c29
1 files changed, 27 insertions, 2 deletions
diff --git a/src/northbridge/amd/amdfam10/misc_control.c b/src/northbridge/amd/amdfam10/misc_control.c
index 4c65bca79f..d6f9fd9437 100644
--- a/src/northbridge/amd/amdfam10/misc_control.c
+++ b/src/northbridge/amd/amdfam10/misc_control.c
@@ -5,6 +5,7 @@
* Copyright (C) Stefan Reinauer
* Copyright (C) 2007 Advanced Micro Devices, Inc.
* Copyright (C) 2015 Timothy Pearson <tpearson@raptorengineeringinc.com>, Raptor Engineering
+ * Copyright (C) 2016 Damien Zammit <damien@zamaudio.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -117,16 +118,25 @@ static void set_agp_aperture(device_t dev, uint32_t pci_id)
static void mcf3_set_resources_fam10h(device_t dev)
{
/* Set the gart apeture */
set_agp_aperture(dev, 0x1203);
/* Set the generic PCI resources */
pci_dev_set_resources(dev);
}
+static void mcf3_set_resources_fam15h_model10(device_t dev)
+{
+ /* Set the gart aperture */
+ set_agp_aperture(dev, 0x1403);
+
+ /* Set the generic PCI resources */
+ pci_dev_set_resources(dev);
+}
+
static void mcf3_set_resources_fam15h(device_t dev)
{
/* Set the gart apeture */
set_agp_aperture(dev, 0x1603);
/* Set the generic PCI resources */
@@ -175,6 +185,15 @@ static struct device_operations mcf3_ops_fam10h = {
.ops_pci = 0,
};
+static struct device_operations mcf3_ops_fam15h_model10 = {
+ .read_resources = mcf3_read_resources,
+ .set_resources = mcf3_set_resources_fam15h_model10,
+ .enable_resources = pci_dev_enable_resources,
+ .init = misc_control_init,
+ .scan_bus = 0,
+ .ops_pci = 0,
+};
+
static struct device_operations mcf3_ops_fam15h = {
.read_resources = mcf3_read_resources,
.set_resources = mcf3_set_resources_fam15h,
@@ -190,6 +209,12 @@ static const struct pci_driver mcf3_driver __pci_driver = {
.device = 0x1203,
};
+static const struct pci_driver mcf3_driver_fam15_model10 __pci_driver = {
+ .ops = &mcf3_ops_fam15h_model10,
+ .vendor = PCI_VENDOR_ID_AMD,
+ .device = 0x1403,
+};
+
static const struct pci_driver mcf3_driver_fam15 __pci_driver = {
.ops = &mcf3_ops_fam15h,
.vendor = PCI_VENDOR_ID_AMD,
@@ -117,16 +118,25 @@ static void set_agp_aperture(device_t dev, uint32_t pci_id)
static void mcf3_set_resources_fam10h(device_t dev)
{
- /* Set the gart apeture */
+ /* Set the gart aperture */
set_agp_aperture(dev, 0x1203);
/* Set the generic PCI resources */
@@ -117,16 +118,25 @@ static void set_agp_aperture(device_t dev, uint32_t pci_id)
static void mcf3_set_resources_fam15h(device_t dev)
{
- /* Set the gart apeture */
+ /* Set the gart aperture */
set_agp_aperture(dev, 0x1603);
/* Set the generic PCI resources */